include_midi!() { /* proc-macro */ }Expand description
Import a midi file. Only available if you have the midi feature enabled (enabled by default).
This is currently experimental, and many types of MIDI file or MIDI features are not supported.
Takes 2 arguments, an SF2 file and a midi file.